Skip to main contentCrate dm_checks
Source - CheckIssue
- A single issue found during a health check.
- CheckReport
- Aggregated results from all health checks.
- CheckType
- The type of health check that produced an issue.
- check_broken_links
- Detect broken cross-references in related_docs, supersedes, and superseded_by fields.
- check_frontmatter
- Validate frontmatter for all documents and convert issues to CheckIssues.
- check_orphans
- Detect orphaned design documents: accepted without PRs, stale acceptances.
- check_stale
- Detect stale documents: overdue reviews, old last-updated dates, missing review dates.
- format_report
- Format a check report as human-readable text.
- run_all_checks
- Run all health checks and return an aggregated report.